@@ -1,25 +1,16 @@
-#if (defined(__cplusplus) || defined(__STDC__) || defined(c_plusplus))
-#define NEW_STYLE 1
-#else
-#define NEW_STYLE 0
-#endif
+#include <config.h>
 
 #include <stdio.h>
+#include <string.h>
+#include <ctype.h>
 
-#if NEW_STYLE
-#define VOID	void
-#define ARGS(parenthesized_list) parenthesized_list
+#if defined(HAVE_STDLIB_H)
 #include <stdlib.h>
-#else /* K&R style */
-#define VOID
-#define ARGS(parenthesized_list) ()
-#endif /* NEW_STYLE */
-
-#if !defined(EXIT_SUCCESS)
-#define EXIT_SUCCESS	0
-#define EXIT_FAILURE	1
 #endif
 
+#include "args.h"
+#include "bibyydcl.h"
+
 #define	ERROR_PREFIX	"??"	/* this prefixes all error messages */
 
 extern long		line_number;
@@ -28,21 +19,6 @@ extern const char	*the_filename;
 static void		dolex ARGS((void));
 int			main ARGS((int argc_, char *argv_[]));
 
-#if __sgi
-/* SGI C++ erroneously assumes that yylex() is a C function instead of
-a C++ function, sigh... */
-#ifdef __cplusplus
-extern "C" {
-int			yylex ARGS((void));
-}
-#else
-int			yylex ARGS((void));
-#endif
-#else /* NOT __sgi */
-int			yylex ARGS((void));
-#endif /* __sgi */
-
-
 #if NEW_STYLE
 int
 main(int argc, char *argv[])
